@@ -1,36 +1,23 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "gravatarresolvurljob.h"
+#include "gravatar_debug.h"
 #include "misc/gravatarcache.h"
 #include "misc/hash.h"
-#include "gravatar_debug.h"
 #include <PimCommon/NetworkManager>
 
 #include <QCryptographicHash>
-#include <QPixmap>
-#include <QUrlQuery>
 #include <QNetworkConfigurationManager>
+#include <QNetworkReply>
+#include <QUrlQuery>
 
 using namespace Gravatar;
 
-class Q_DECL_HIDDEN Gravatar::GravatarResolvUrlJobPrivate
+class Gravatar::GravatarResolvUrlJobPrivate
 {
 public:
     GravatarResolvUrlJobPrivate()
@@ -43,11 +30,7 @@ public:
     QNetworkAccessManager *mNetworkAccessManager = nullptr;
     int mSize = 80;
 
-    enum Backend {
-        None = 0x0,
-        Libravatar = 0x1,
-        Gravatar = 0x2
-    };
+    enum Backend { None = 0x0, Libravatar = 0x1, Gravatar = 0x2 };
     int mBackends = Gravatar;
 
     bool mHasGravatar = false;
@@ -60,15 +43,12 @@ GravatarResolvUrlJob::GravatarResolvUrlJob(QObject *parent)
 {
 }
 
-GravatarResolvUrlJob::~GravatarResolvUrlJob()
-{
-    delete d;
-}
+GravatarResolvUrlJob::~GravatarResolvUrlJob() = default;
 
 bool GravatarResolvUrlJob::canStart() const
 {
     if (PimCommon::NetworkManager::self()->networkConfigureManager()->isOnline()) {
-        //qCDebug(GRAVATAR_LOG) << "email " << d->mEmail;
+        // qCDebug(GRAVATAR_LOG) << "email " << d->mEmail;
         return !d->mEmail.trimmed().isEmpty() && (d->mEmail.contains(QLatin1Char('@')));
     } else {
         return false;
@@ -93,16 +73,11 @@ void GravatarResolvUrlJob::startNetworkManager(const QUrl &url)
         d->mNetworkAccessManager->setStrictTransportSecurityEnabled(true);
         d->mNetworkAccessManager->enableStrictTransportSecurityStore(true);
         connect(d->mNetworkAccessManager, &QNetworkAccessManager::finished, this, &GravatarResolvUrlJob::slotFinishLoadPixmap);
-
     }
 
     QNetworkRequest req(url);
     req.setAttribute(QNetworkRequest::HttpPipeliningAllowedAttribute, true);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    req.setAttribute(QNetworkRequest::HTTP2AllowedAttribute, true);
-#else
     req.setAttribute(QNetworkRequest::Http2AllowedAttribute, true);
-#endif
     d->mNetworkAccessManager->get(req);
 }
 
@@ -138,7 +113,7 @@ void GravatarResolvUrlJob::processNextBackend()
         url = createUrl(false);
     }
 
-    //qDebug() << " url " << url;
+    // qDebug() << " url " << url;
     Q_EMIT resolvUrl(url);
     if (!cacheLookup(d->mCalculatedHash)) {
         startNetworkManager(url);
@@ -153,7 +128,7 @@ void GravatarResolvUrlJob::slotFinishLoadPixmap(QNetworkReply *reply)
         const QByteArray data = reply->readAll();
         d->mPixmap.loadFromData(data);
         d->mHasGravatar = true;
-        //For the moment don't use cache other we will store a lot of pixmap
+        // For the moment don't use cache other we will store a lot of pixmap
         if (!d->mUseDefaultPixmap) {
             GravatarCache::self()->saveGravatarPixmap(d->mCalculatedHash, d->mPixmap);
         }
@@ -192,10 +167,11 @@ bool GravatarResolvUrlJob::fallbackGravatar() const
 
 void GravatarResolvUrlJob::setFallbackGravatar(bool fallbackGravatar)
 {
-    if (fallbackGravatar)
+    if (fallbackGravatar) {
         d->mBackends |= GravatarResolvUrlJobPrivate::Gravatar;
-    else
+    } else {
         d->mBackends &= ~GravatarResolvUrlJobPrivate::Gravatar;
+    }
 }
 
 bool GravatarResolvUrlJob::useLibravatar() const
@@ -205,10 +181,11 @@ bool GravatarResolvUrlJob::useLibravatar() const
 
 void GravatarResolvUrlJob::setUseLibravatar(bool useLibravatar)
 {
-    if (useLibravatar)
+    if (useLibravatar) {
         d->mBackends |= GravatarResolvUrlJobPrivate::Libravatar;
-    else
+    } else {
         d->mBackends &= ~GravatarResolvUrlJobPrivate::Libravatar;
+    }
 }
 
 bool GravatarResolvUrlJob::useDefaultPixmap() const
@@ -255,7 +232,7 @@ QUrl GravatarResolvUrlJob::createUrl(bool useLibravatar)
     }
     QUrlQuery query;
     if (!d->mUseDefaultPixmap) {
-        //Add ?d=404
+        // Add ?d=404
         query.addQueryItem(QStringLiteral("d"), QStringLiteral("404"));
     }
     if (d->mSize != 80) {
