@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "gravatarcache.h"
@@ -35,11 +22,10 @@ using namespace Gravatar;
 
 Q_GLOBAL_STATIC(GravatarCache, s_gravatarCache)
 
-class Q_DECL_HIDDEN Gravatar::GravatarCachePrivate
+class Gravatar::GravatarCachePrivate
 {
 public:
-    template<typename T>
-    inline void insertMissingHash(std::vector<T> &vec, const T &hash)
+    template<typename T> inline void insertMissingHash(std::vector<T> &vec, const T &hash)
     {
         auto it = std::lower_bound(vec.begin(), vec.end(), hash);
         if (it != vec.end() && *it == hash) {
@@ -48,8 +34,7 @@ public:
         vec.insert(it, hash);
     }
 
-    template<typename T>
-    inline void saveVector(const std::vector<T> &vec, const QString &fileName)
+    template<typename T> inline void saveVector(const std::vector<T> &vec, const QString &fileName)
     {
         QSaveFile f(mGravatarPath + fileName);
         if (!f.open(QFile::WriteOnly)) {
@@ -62,8 +47,7 @@ public:
         f.commit();
     }
 
-    template<typename T>
-    inline void loadVector(std::vector<T> &vec, const QString &fileName)
+    template<typename T> inline void loadVector(std::vector<T> &vec, const QString &fileName)
     {
         if (!vec.empty()) { // already loaded
             return;
@@ -91,15 +75,12 @@ GravatarCache::GravatarCache()
     : d(new Gravatar::GravatarCachePrivate)
 {
     d->mCachePixmap.setMaxCost(20);
-    //Make sure that this folder is created. Otherwise we can't store gravatar
+    // Make sure that this folder is created. Otherwise we can't store gravatar
     d->mGravatarPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/gravatar/");
     QDir().mkpath(d->mGravatarPath);
 }
 
-GravatarCache::~GravatarCache()
-{
-    delete d;
-}
+GravatarCache::~GravatarCache() = default;
 
 GravatarCache *GravatarCache::self()
 {
@@ -139,7 +120,7 @@ void GravatarCache::saveMissingGravatar(const Hash &hash)
 QPixmap GravatarCache::loadGravatarPixmap(const Hash &hash, bool &gravatarStored)
 {
     gravatarStored = false;
-    //qCDebug(GRAVATAR_LOG) << " hashStr" << hash.hexString();
+    // qCDebug(GRAVATAR_LOG) << " hashStr" << hash.hexString();
     if (!hash.isValid()) {
         return QPixmap();
     }
@@ -203,7 +184,7 @@ void GravatarCache::clearAllCache()
     if (!path.isEmpty()) {
         QDir dir(path);
         if (dir.exists()) {
-            const QFileInfoList list = dir.entryInfoList();  // get list of matching files and delete all
+            const QFileInfoList list = dir.entryInfoList(); // get list of matching files and delete all
             for (const QFileInfo &it : list) {
                 dir.remove(it.fileName());
             }
