@@ -1,37 +1,24 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "gravatarconfigwidget.h"
-#include "misc/gravatarcache.h"
 #include "gravatarconfiguresettingsdialog.h"
-#include <KLocalizedString>
-#include <QCheckBox>
-#include <QPushButton>
-#include <QPointer>
-#include <QHBoxLayout>
 #include "gravatarsettings.h"
+#include "misc/gravatarcache.h"
+#include <KLocalizedString>
 #include <PimCommon/ConfigureImmutableWidgetUtils>
+#include <QCheckBox>
+#include <QHBoxLayout>
+#include <QPointer>
+#include <QPushButton>
 
 using namespace Gravatar;
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 
-class Q_DECL_HIDDEN Gravatar::GravatarConfigWidgetPrivate
+class Gravatar::GravatarConfigWidgetPrivate
 {
 public:
     GravatarConfigWidgetPrivate()
@@ -46,7 +33,7 @@ GravatarConfigWidget::GravatarConfigWidget(QWidget *parent)
     : QWidget(parent)
     , d(new Gravatar::GravatarConfigWidgetPrivate)
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
     d->mEnableGravatarSupport = new QCheckBox(i18n("Enable Gravatar Support"));
@@ -64,10 +51,7 @@ GravatarConfigWidget::GravatarConfigWidget(QWidget *parent)
     updateWidgetState(false);
 }
 
-GravatarConfigWidget::~GravatarConfigWidget()
-{
-    delete d;
-}
+GravatarConfigWidget::~GravatarConfigWidget() = default;
 
 void GravatarConfigWidget::slotConfigureSettings()
 {
